@@ -3,7 +3,7 @@ package System::Info;
 use strict;
 use warnings;
 
-our $VERSION = "0.060";
+our $VERSION = "0.062";
 
 use base "Exporter";
 our @EXPORT_OK = qw( &sysinfo &sysinfo_hash &si_uname );
@@ -252,9 +252,14 @@ type, CPU speed, or Memory.
     osvers   => $si->distro,
     };
 
+=head2 Devel::CheckOS
+
+This one does not return the OS information as such, but features an
+alternative to C<$^O>.
+
 =head1 COPYRIGHT AND LICENSE
 
-(c) 2016-2020, Abe Timmerman & H.Merijn Brand, All rights reserved.
+(c) 2016-2022, Abe Timmerman & H.Merijn Brand, All rights reserved.
 
 With contributions from Jarkko Hietaniemi, Campo Weijerman, Alan Burlison,
 Allen Smith, Alain Barbet, Dominic Dunlop, Rich Rauenzahn, David Cantrell.
